from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class IntImp_ConstIsoparametric(IntEnum):
	IntImp_UIsoparametricOnCaro1: int = ...
	IntImp_VIsoparametricOnCaro1: int = ...
	IntImp_UIsoparametricOnCaro2: int = ...
	IntImp_VIsoparametricOnCaro2: int = ...
IntImp_UIsoparametricOnCaro1 = IntImp_ConstIsoparametric.IntImp_UIsoparametricOnCaro1
IntImp_VIsoparametricOnCaro1 = IntImp_ConstIsoparametric.IntImp_VIsoparametricOnCaro1
IntImp_UIsoparametricOnCaro2 = IntImp_ConstIsoparametric.IntImp_UIsoparametricOnCaro2
IntImp_VIsoparametricOnCaro2 = IntImp_ConstIsoparametric.IntImp_VIsoparametricOnCaro2

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TopoDSToStep module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_topodstostep.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TopoDSToStep
else:
    import _TopoDSToStep

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TopoDSToStep.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TopoDSToStep.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopoDSToStep.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopoDSToStep.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TopoDSToStep.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TopoDSToStep.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TopoDSToStep.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TopoDSToStep.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TopoDSToStep.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TopoDSToStep.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopoDSToStep.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TopoDSToStep.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TopoDSToStep.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopoDSToStep.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopoDSToStep.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopoDSToStep.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TopoDSToStep.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TopoDSToStep:
_TopoDSToStep.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TopoDSToStep.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Transfer
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.Interface
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepData
import OCC.Core.Resource
import OCC.Core.StepRepr
import OCC.Core.StepBasic

from enum import IntEnum
from OCC.Core.Exception import *

TopoDSToStep_EdgeDone = _TopoDSToStep.TopoDSToStep_EdgeDone
TopoDSToStep_NonManifoldEdge = _TopoDSToStep.TopoDSToStep_NonManifoldEdge
TopoDSToStep_EdgeOther = _TopoDSToStep.TopoDSToStep_EdgeOther
TopoDSToStep_BuilderDone = _TopoDSToStep.TopoDSToStep_BuilderDone
TopoDSToStep_NoFaceMapped = _TopoDSToStep.TopoDSToStep_NoFaceMapped
TopoDSToStep_BuilderOther = _TopoDSToStep.TopoDSToStep_BuilderOther
TopoDSToStep_VertexDone = _TopoDSToStep.TopoDSToStep_VertexDone
TopoDSToStep_VertexOther = _TopoDSToStep.TopoDSToStep_VertexOther
TopoDSToStep_WireDone = _TopoDSToStep.TopoDSToStep_WireDone
TopoDSToStep_NonManifoldWire = _TopoDSToStep.TopoDSToStep_NonManifoldWire
TopoDSToStep_WireOther = _TopoDSToStep.TopoDSToStep_WireOther
TopoDSToStep_FaceDone = _TopoDSToStep.TopoDSToStep_FaceDone
TopoDSToStep_InfiniteFace = _TopoDSToStep.TopoDSToStep_InfiniteFace
TopoDSToStep_NonManifoldFace = _TopoDSToStep.TopoDSToStep_NonManifoldFace
TopoDSToStep_NoWireMapped = _TopoDSToStep.TopoDSToStep_NoWireMapped
TopoDSToStep_FaceOther = _TopoDSToStep.TopoDSToStep_FaceOther
TopoDSToStep_FacetedDone = _TopoDSToStep.TopoDSToStep_FacetedDone
TopoDSToStep_SurfaceNotPlane = _TopoDSToStep.TopoDSToStep_SurfaceNotPlane
TopoDSToStep_PCurveNotLinear = _TopoDSToStep.TopoDSToStep_PCurveNotLinear


class TopoDSToStep_MakeEdgeError(IntEnum):
	TopoDSToStep_EdgeDone = 0
	TopoDSToStep_NonManifoldEdge = 1
	TopoDSToStep_EdgeOther = 2
TopoDSToStep_EdgeDone = TopoDSToStep_MakeEdgeError.TopoDSToStep_EdgeDone
TopoDSToStep_NonManifoldEdge = TopoDSToStep_MakeEdgeError.TopoDSToStep_NonManifoldEdge
TopoDSToStep_EdgeOther = TopoDSToStep_MakeEdgeError.TopoDSToStep_EdgeOther

class TopoDSToStep_BuilderError(IntEnum):
	TopoDSToStep_BuilderDone = 0
	TopoDSToStep_NoFaceMapped = 1
	TopoDSToStep_BuilderOther = 2
TopoDSToStep_BuilderDone = TopoDSToStep_BuilderError.TopoDSToStep_BuilderDone
TopoDSToStep_NoFaceMapped = TopoDSToStep_BuilderError.TopoDSToStep_NoFaceMapped
TopoDSToStep_BuilderOther = TopoDSToStep_BuilderError.TopoDSToStep_BuilderOther

class TopoDSToStep_MakeVertexError(IntEnum):
	TopoDSToStep_VertexDone = 0
	TopoDSToStep_VertexOther = 1
TopoDSToStep_VertexDone = TopoDSToStep_MakeVertexError.TopoDSToStep_VertexDone
TopoDSToStep_VertexOther = TopoDSToStep_MakeVertexError.TopoDSToStep_VertexOther

class TopoDSToStep_MakeWireError(IntEnum):
	TopoDSToStep_WireDone = 0
	TopoDSToStep_NonManifoldWire = 1
	TopoDSToStep_WireOther = 2
TopoDSToStep_WireDone = TopoDSToStep_MakeWireError.TopoDSToStep_WireDone
TopoDSToStep_NonManifoldWire = TopoDSToStep_MakeWireError.TopoDSToStep_NonManifoldWire
TopoDSToStep_WireOther = TopoDSToStep_MakeWireError.TopoDSToStep_WireOther

class TopoDSToStep_MakeFaceError(IntEnum):
	TopoDSToStep_FaceDone = 0
	TopoDSToStep_InfiniteFace = 1
	TopoDSToStep_NonManifoldFace = 2
	TopoDSToStep_NoWireMapped = 3
	TopoDSToStep_FaceOther = 4
TopoDSToStep_FaceDone = TopoDSToStep_MakeFaceError.TopoDSToStep_FaceDone
TopoDSToStep_InfiniteFace = TopoDSToStep_MakeFaceError.TopoDSToStep_InfiniteFace
TopoDSToStep_NonManifoldFace = TopoDSToStep_MakeFaceError.TopoDSToStep_NonManifoldFace
TopoDSToStep_NoWireMapped = TopoDSToStep_MakeFaceError.TopoDSToStep_NoWireMapped
TopoDSToStep_FaceOther = TopoDSToStep_MakeFaceError.TopoDSToStep_FaceOther

class TopoDSToStep_FacetedError(IntEnum):
	TopoDSToStep_FacetedDone = 0
	TopoDSToStep_SurfaceNotPlane = 1
	TopoDSToStep_PCurveNotLinear = 2
TopoDSToStep_FacetedDone = TopoDSToStep_FacetedError.TopoDSToStep_FacetedDone
TopoDSToStep_SurfaceNotPlane = TopoDSToStep_FacetedError.TopoDSToStep_SurfaceNotPlane
TopoDSToStep_PCurveNotLinear = TopoDSToStep_FacetedError.TopoDSToStep_PCurveNotLinear

class topodstostep(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddResult(*args) -> "void":
        r"""
        Adds an entity into the list of results (binders) for shape stored in finderprocess.

        Parameters
        ----------
        FP: Transfer_FinderProcess
        Shape: TopoDS_Shape
        entity: Standard_Transient

        Returns
        -------
        None
        Adds all entities recorded in tool into the map of results (binders) stored in finderprocess.

        Parameters
        ----------
        FP: Transfer_FinderProcess
        Tool: TopoDSToStep_Tool

        Returns
        -------
        None

        """
        return _TopoDSToStep.topodstostep_AddResult(*args)

    @staticmethod
    def DecodeBuilderError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDSToStep_BuilderError

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _TopoDSToStep.topodstostep_DecodeBuilderError(*args)

    @staticmethod
    def DecodeEdgeError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDSToStep_MakeEdgeError

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _TopoDSToStep.topodstostep_DecodeEdgeError(*args)

    @staticmethod
    def DecodeFaceError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDSToStep_MakeFaceError

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _TopoDSToStep.topodstostep_DecodeFaceError(*args)

    @staticmethod
    def DecodeVertexError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns a new shape without undirect surfaces.

        Parameters
        ----------
        E: TopoDSToStep_MakeVertexError

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _TopoDSToStep.topodstostep_DecodeVertexError(*args)

    @staticmethod
    def DecodeWireError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDSToStep_MakeWireError

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _TopoDSToStep.topodstostep_DecodeWireError(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopoDSToStep.topodstostep_swiginit(self, _TopoDSToStep.new_topodstostep())
    __swig_destroy__ = _TopoDSToStep.delete_topodstostep

# Register topodstostep in _TopoDSToStep:
_TopoDSToStep.topodstostep_swigregister(topodstostep)

def topodstostep_AddResult(*args) -> "void":
    r"""
    Adds an entity into the list of results (binders) for shape stored in finderprocess.

    Parameters
    ----------
    FP: Transfer_FinderProcess
    Shape: TopoDS_Shape
    entity: Standard_Transient

    Returns
    -------
    None
    Adds all entities recorded in tool into the map of results (binders) stored in finderprocess.

    Parameters
    ----------
    FP: Transfer_FinderProcess
    Tool: TopoDSToStep_Tool

    Returns
    -------
    None

    """
    return _TopoDSToStep.topodstostep_AddResult(*args)

def topodstostep_DecodeBuilderError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDSToStep_BuilderError

    Returns
    -------
    opencascade::handle<TCollection_HAsciiString>

    """
    return _TopoDSToStep.topodstostep_DecodeBuilderError(*args)

def topodstostep_DecodeEdgeError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDSToStep_MakeEdgeError

    Returns
    -------
    opencascade::handle<TCollection_HAsciiString>

    """
    return _TopoDSToStep.topodstostep_DecodeEdgeError(*args)

def topodstostep_DecodeFaceError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDSToStep_MakeFaceError

    Returns
    -------
    opencascade::handle<TCollection_HAsciiString>

    """
    return _TopoDSToStep.topodstostep_DecodeFaceError(*args)

def topodstostep_DecodeVertexError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
    r"""
    Returns a new shape without undirect surfaces.

    Parameters
    ----------
    E: TopoDSToStep_MakeVertexError

    Returns
    -------
    opencascade::handle<TCollection_HAsciiString>

    """
    return _TopoDSToStep.topodstostep_DecodeVertexError(*args)

def topodstostep_DecodeWireError(*args) -> "opencascade::handle< TCollection_HAsciiString >":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDSToStep_MakeWireError

    Returns
    -------
    opencascade::handle<TCollection_HAsciiString>

    """
    return _TopoDSToStep.topodstostep_DecodeWireError(*args)

class TopoDSToStep_FacetedTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def CheckTopoDSShape(*args) -> "TopoDSToStep_FacetedError":
        r"""
        No available documentation.

        Parameters
        ----------
        SH: TopoDS_Shape

        Returns
        -------
        TopoDSToStep_FacetedError

        """
        return _TopoDSToStep.TopoDSToStep_FacetedTool_CheckTopoDSShape(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopoDSToStep.TopoDSToStep_FacetedTool_swiginit(self, _TopoDSToStep.new_TopoDSToStep_FacetedTool())
    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_FacetedTool

# Register TopoDSToStep_FacetedTool in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_FacetedTool_swigregister(TopoDSToStep_FacetedTool)

def TopoDSToStep_FacetedTool_CheckTopoDSShape(*args) -> "TopoDSToStep_FacetedError":
    r"""
    No available documentation.

    Parameters
    ----------
    SH: TopoDS_Shape

    Returns
    -------
    TopoDSToStep_FacetedError

    """
    return _TopoDSToStep.TopoDSToStep_FacetedTool_CheckTopoDSShape(*args)

class TopoDSToStep_Root(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopoDSToStep.TopoDSToStep_Root_IsDone(self, *args)

    def GetTolerance(self) -> "Standard_Real":
        r"""GetTolerance(TopoDSToStep_Root self) -> Standard_Real"""
        return _TopoDSToStep.TopoDSToStep_Root_GetTolerance(self)

    def SetTolerance(self, value: "Standard_Real") -> "void":
        r"""SetTolerance(TopoDSToStep_Root self, Standard_Real value)"""
        return _TopoDSToStep.TopoDSToStep_Root_SetTolerance(self, value)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_Root

# Register TopoDSToStep_Root in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_Root_swigregister(TopoDSToStep_Root)

class TopoDSToStep_Tool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        M: MoniTool_DataMapOfShapeTransient
        FacetedContext: bool

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_Tool_swiginit(self, _TopoDSToStep.new_TopoDSToStep_Tool(*args))

    def Bind(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: StepShape_TopologicalRepresentationItem

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_Bind(self, *args)

    def CurrentEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Edge

        """
        return _TopoDSToStep.TopoDSToStep_Tool_CurrentEdge(self, *args)

    def CurrentFace(self, *args) -> "TopoDS_Face const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Face

        """
        return _TopoDSToStep.TopoDSToStep_Tool_CurrentFace(self, *args)

    def CurrentShell(self, *args) -> "TopoDS_Shell const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shell

        """
        return _TopoDSToStep.TopoDSToStep_Tool_CurrentShell(self, *args)

    def CurrentVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _TopoDSToStep.TopoDSToStep_Tool_CurrentVertex(self, *args)

    def CurrentWire(self, *args) -> "TopoDS_Wire const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Wire

        """
        return _TopoDSToStep.TopoDSToStep_Tool_CurrentWire(self, *args)

    def Faceted(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopoDSToStep.TopoDSToStep_Tool_Faceted(self, *args)

    def Find(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem >":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _TopoDSToStep.TopoDSToStep_Tool_Find(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        M: MoniTool_DataMapOfShapeTransient
        FacetedContext: bool

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_Init(self, *args)

    def IsBound(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _TopoDSToStep.TopoDSToStep_Tool_IsBound(self, *args)

    def Lowest3DTolerance(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _TopoDSToStep.TopoDSToStep_Tool_Lowest3DTolerance(self, *args)

    def Map(self, *args) -> "MoniTool_DataMapOfShapeTransient const &":
        r"""
        No available documentation.

        Returns
        -------
        MoniTool_DataMapOfShapeTransient

        """
        return _TopoDSToStep.TopoDSToStep_Tool_Map(self, *args)

    def PCurveMode(self, *args) -> "Standard_Integer":
        r"""
        Returns mode for writing pcurves (initialized by parameter write.surfacecurve.mode).

        Returns
        -------
        int

        """
        return _TopoDSToStep.TopoDSToStep_Tool_PCurveMode(self, *args)

    def SetCurrentEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_SetCurrentEdge(self, *args)

    def SetCurrentFace(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_SetCurrentFace(self, *args)

    def SetCurrentShell(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shell

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_SetCurrentShell(self, *args)

    def SetCurrentVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_SetCurrentVertex(self, *args)

    def SetCurrentWire(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W: TopoDS_Wire

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_SetCurrentWire(self, *args)

    def SetSurfaceReversed(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: bool

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Tool_SetSurfaceReversed(self, *args)

    def SurfaceReversed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopoDSToStep.TopoDSToStep_Tool_SurfaceReversed(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_Tool

# Register TopoDSToStep_Tool in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_Tool_swigregister(TopoDSToStep_Tool)

class TopoDSToStep_Builder(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_Builder_swiginit(self, _TopoDSToStep.new_TopoDSToStep_Builder(*args))

    def Error(self, *args) -> "TopoDSToStep_BuilderError":
        r"""
        No available documentation.

        Returns
        -------
        TopoDSToStep_BuilderError

        """
        return _TopoDSToStep.TopoDSToStep_Builder_Error(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_Builder_Init(self, *args)

    def Value(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _TopoDSToStep.TopoDSToStep_Builder_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_Builder

# Register TopoDSToStep_Builder in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_Builder_swigregister(TopoDSToStep_Builder)

class TopoDSToStep_MakeBrepWithVoids(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Solid
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeBrepWithVoids_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeBrepWithVoids(*args))

    def Value(self, *args) -> "opencascade::handle< StepShape_BrepWithVoids > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_BrepWithVoids>

        """
        return _TopoDSToStep.TopoDSToStep_MakeBrepWithVoids_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeBrepWithVoids

# Register TopoDSToStep_MakeBrepWithVoids in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeBrepWithVoids_swigregister(TopoDSToStep_MakeBrepWithVoids)

class TopoDSToStep_MakeFacetedBrep(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shell
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Solid
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeFacetedBrep_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeFacetedBrep(*args))

    def Value(self, *args) -> "opencascade::handle< StepShape_FacetedBrep > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_FacetedBrep>

        """
        return _TopoDSToStep.TopoDSToStep_MakeFacetedBrep_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeFacetedBrep

# Register TopoDSToStep_MakeFacetedBrep in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeFacetedBrep_swigregister(TopoDSToStep_MakeFacetedBrep)

class TopoDSToStep_MakeFacetedBrepAndBrepWithVoids(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Solid
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeFacetedBrepAndBrepWithVoids_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeFacetedBrepAndBrepWithVoids(*args))

    def Value(self, *args) -> "opencascade::handle< StepShape_FacetedBrepAndBrepWithVoids > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_FacetedBrepAndBrepWithVoids>

        """
        return _TopoDSToStep.TopoDSToStep_MakeFacetedBrepAndBrepWithVoids_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeFacetedBrepAndBrepWithVoids

# Register TopoDSToStep_MakeFacetedBrepAndBrepWithVoids in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeFacetedBrepAndBrepWithVoids_swigregister(TopoDSToStep_MakeFacetedBrepAndBrepWithVoids)

class TopoDSToStep_MakeGeometricCurveSet(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        SH: TopoDS_Shape
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeGeometricCurveSet_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeGeometricCurveSet(*args))

    def Value(self, *args) -> "opencascade::handle< StepShape_GeometricCurveSet > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_GeometricCurveSet>

        """
        return _TopoDSToStep.TopoDSToStep_MakeGeometricCurveSet_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeGeometricCurveSet

# Register TopoDSToStep_MakeGeometricCurveSet in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeGeometricCurveSet_swigregister(TopoDSToStep_MakeGeometricCurveSet)

class TopoDSToStep_MakeManifoldSolidBrep(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shell
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Solid
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeManifoldSolidBrep_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeManifoldSolidBrep(*args))

    def Value(self, *args) -> "opencascade::handle< StepShape_ManifoldSolidBrep > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_ManifoldSolidBrep>

        """
        return _TopoDSToStep.TopoDSToStep_MakeManifoldSolidBrep_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeManifoldSolidBrep

# Register TopoDSToStep_MakeManifoldSolidBrep in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeManifoldSolidBrep_swigregister(TopoDSToStep_MakeManifoldSolidBrep)

class TopoDSToStep_MakeShellBasedSurfaceModel(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shell
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Solid
        FP: Transfer_FinderProcess
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeShellBasedSurfaceModel_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeShellBasedSurfaceModel(*args))

    def Value(self, *args) -> "opencascade::handle< StepShape_ShellBasedSurfaceModel > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_ShellBasedSurfaceModel>

        """
        return _TopoDSToStep.TopoDSToStep_MakeShellBasedSurfaceModel_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeShellBasedSurfaceModel

# Register TopoDSToStep_MakeShellBasedSurfaceModel in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeShellBasedSurfaceModel_swigregister(TopoDSToStep_MakeShellBasedSurfaceModel)

class TopoDSToStep_MakeStepEdge(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeStepEdge_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeStepEdge(*args))

    def Error(self, *args) -> "TopoDSToStep_MakeEdgeError":
        r"""
        No available documentation.

        Returns
        -------
        TopoDSToStep_MakeEdgeError

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepEdge_Error(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepEdge_Init(self, *args)

    def Value(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepEdge_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeStepEdge

# Register TopoDSToStep_MakeStepEdge in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeStepEdge_swigregister(TopoDSToStep_MakeStepEdge)

class TopoDSToStep_MakeStepFace(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeStepFace_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeStepFace(*args))

    def Error(self, *args) -> "TopoDSToStep_MakeFaceError":
        r"""
        No available documentation.

        Returns
        -------
        TopoDSToStep_MakeFaceError

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepFace_Error(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepFace_Init(self, *args)

    def Value(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepFace_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeStepFace

# Register TopoDSToStep_MakeStepFace in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeStepFace_swigregister(TopoDSToStep_MakeStepFace)

class TopoDSToStep_MakeStepVertex(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeStepVertex_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeStepVertex(*args))

    def Error(self, *args) -> "TopoDSToStep_MakeVertexError":
        r"""
        No available documentation.

        Returns
        -------
        TopoDSToStep_MakeVertexError

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepVertex_Error(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepVertex_Init(self, *args)

    def Value(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepVertex_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeStepVertex

# Register TopoDSToStep_MakeStepVertex in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeStepVertex_swigregister(TopoDSToStep_MakeStepVertex)

class TopoDSToStep_MakeStepWire(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        W: TopoDS_Wire
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_MakeStepWire_swiginit(self, _TopoDSToStep.new_TopoDSToStep_MakeStepWire(*args))

    def Error(self, *args) -> "TopoDSToStep_MakeWireError":
        r"""
        No available documentation.

        Returns
        -------
        TopoDSToStep_MakeWireError

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepWire_Error(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W: TopoDS_Wire
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepWire_Init(self, *args)

    def Value(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _TopoDSToStep.TopoDSToStep_MakeStepWire_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_MakeStepWire

# Register TopoDSToStep_MakeStepWire in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_MakeStepWire_swigregister(TopoDSToStep_MakeStepWire)

class TopoDSToStep_WireframeBuilder(TopoDSToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        _TopoDSToStep.TopoDSToStep_WireframeBuilder_swiginit(self, _TopoDSToStep.new_TopoDSToStep_WireframeBuilder(*args))

    def Error(self, *args) -> "TopoDSToStep_BuilderError":
        r"""
        No available documentation.

        Returns
        -------
        TopoDSToStep_BuilderError

        """
        return _TopoDSToStep.TopoDSToStep_WireframeBuilder_Error(self, *args)

    def GetTrimmedCurveFromEdge(self, *args) -> "Standard_Boolean":
        r"""
        Extraction of trimmed curves from topods_edge for the creation of a geometricallyboundedwireframerepresentation.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face
        M: MoniTool_DataMapOfShapeTransient
        L: TColStd_HSequenceOfTransient

        Returns
        -------
        bool

        """
        return _TopoDSToStep.TopoDSToStep_WireframeBuilder_GetTrimmedCurveFromEdge(self, *args)

    def GetTrimmedCurveFromFace(self, *args) -> "Standard_Boolean":
        r"""
        Extraction of trimmed curves from topods_face for the creation of a geometricallyboundedwireframerepresentation.

        Parameters
        ----------
        F: TopoDS_Face
        M: MoniTool_DataMapOfShapeTransient
        L: TColStd_HSequenceOfTransient

        Returns
        -------
        bool

        """
        return _TopoDSToStep.TopoDSToStep_WireframeBuilder_GetTrimmedCurveFromFace(self, *args)

    def GetTrimmedCurveFromShape(self, *args) -> "Standard_Boolean":
        r"""
        Extraction of trimmed curves from any topods_shape for the creation of a geometricallyboundedwireframerepresentation.

        Parameters
        ----------
        S: TopoDS_Shape
        M: MoniTool_DataMapOfShapeTransient
        L: TColStd_HSequenceOfTransient

        Returns
        -------
        bool

        """
        return _TopoDSToStep.TopoDSToStep_WireframeBuilder_GetTrimmedCurveFromShape(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopoDSToStep_Tool
        FP: Transfer_FinderProcess

        Returns
        -------
        None

        """
        return _TopoDSToStep.TopoDSToStep_WireframeBuilder_Init(self, *args)

    def Value(self, *args) -> "opencascade::handle< TColStd_HSequenceOfTransient > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TColStd_HSequenceOfTransient>

        """
        return _TopoDSToStep.TopoDSToStep_WireframeBuilder_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopoDSToStep.delete_TopoDSToStep_WireframeBuilder

# Register TopoDSToStep_WireframeBuilder in _TopoDSToStep:
_TopoDSToStep.TopoDSToStep_WireframeBuilder_swigregister(TopoDSToStep_WireframeBuilder)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *

NCollection_String = NewType('NCollection_String', NCollection_Utf8String)
#the following typedef cannot be wrapped as is
NCollection_Utf16Iter = NewType('NCollection_Utf16Iter', Any)
#the following typedef cannot be wrapped as is
NCollection_Utf16String = NewType('NCollection_Utf16String', Any)
#the following typedef cannot be wrapped as is
NCollection_Utf32Iter = NewType('NCollection_Utf32Iter', Any)
#the following typedef cannot be wrapped as is
NCollection_Utf32String = NewType('NCollection_Utf32String', Any)
#the following typedef cannot be wrapped as is
NCollection_Utf8Iter = NewType('NCollection_Utf8Iter', Any)
#the following typedef cannot be wrapped as is
NCollection_Utf8String = NewType('NCollection_Utf8String', Any)
#the following typedef cannot be wrapped as is
NCollection_UtfWideIter = NewType('NCollection_UtfWideIter', Any)
#the following typedef cannot be wrapped as is
NCollection_UtfWideString = NewType('NCollection_UtfWideString', Any)
Standard_Size = NewType('Standard_Size', int)

class NCollection_StdAllocator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAlloc: NCollection_BaseAllocator) -> None: ...
	@overload
	def __init__(self, X: NCollection_StdAllocator) -> None: ...
	def Allocator(self) -> NCollection_BaseAllocator: ...

#classnotwrapped
class NCollection_Array1: ...

#classnotwrapped
class NCollection_AccAllocator: ...

#classnotwrapped
class NCollection_UtfString: ...

#classnotwrapped
class NCollection_Lerp: ...

#classnotwrapped
class NCollection_WinHeapAllocator: ...

#classnotwrapped
class NCollection_Mat4: ...

#classnotwrapped
class NCollection_AlignedAllocator: ...

#classnotwrapped
class NCollection_Map: ...

#classnotwrapped
class NCollection_SeqNode: ...

#classnotwrapped
class NCollection_BaseSequence: ...

#classnotwrapped
class NCollection_LocalArray: ...

#classnotwrapped
class NCollection_TListNode: ...

#classnotwrapped
class NCollection_DataMap: ...

#classnotwrapped
class NCollection_ListNode: ...

#classnotwrapped
class NCollection_Vector: ...

#classnotwrapped
class NCollection_DoubleMap: ...

#classnotwrapped
class NCollection_UtfIterator: ...

#classnotwrapped
class NCollection_Vec3: ...

#classnotwrapped
class NCollection_UBTree: ...

#classnotwrapped
class NCollection_EBTree: ...

#classnotwrapped
class NCollection_Vec4: ...

#classnotwrapped
class NCollection_Handle: ...

#classnotwrapped
class NCollection_BaseList: ...

#classnotwrapped
class NCollection_SparseArray: ...

#classnotwrapped
class NCollection_BaseVector: ...

#classnotwrapped
class NCollection_IncAllocator: ...

#classnotwrapped
class NCollection_BaseAllocator: ...

#classnotwrapped
class NCollection_SparseArrayBase: ...

#classnotwrapped
class NCollection_IndexedMap: ...

#classnotwrapped
class NCollection_Vec2: ...

#classnotwrapped
class NCollection_List: ...

#classnotwrapped
class NCollection_TListIterator: ...

#classnotwrapped
class NCollection_BaseMap: ...

#classnotwrapped
class NCollection_Buffer: ...

#classnotwrapped
class NCollection_IndexedDataMap: ...

#classnotwrapped
class NCollection_StdAllocator: ...

#classnotwrapped
class NCollection_UBTreeFiller: ...

#classnotwrapped
class NCollection_DefaultHasher: ...

#classnotwrapped
class NCollection_Sequence: ...

#classnotwrapped
class NCollection_Array2: ...

#classnotwrapped
class NCollection_Shared: ...

#classnotwrapped
class NCollection_HeapAllocator: ...

# harray1 classes
# harray2 classes
# hsequence classes

